import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },

  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'dashboard',
      name: 'Dashboard',
      component: () => import('@/views/dashboard/index'),
      meta: { title: '首页', icon: 'dashboard' }
    }]
  },
  {
    path: '/alarm',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'alarm',
      name: 'Alarm',
      component: () => import('@/views/dashboard/index'),
      meta: { title: '告警管理', icon: 'dashboard' }
    }]
  },
  {
    path: '/setting',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'setting',
      name: 'Setting',
      component: () => import('@/views/dashboard/index'),
      meta: { title: '配置管理', icon: 'dashboard' }
    }]
  },
  {
    path: '/monitor',
    component: Layout,
    redirect: '/dashboard',
    name: '监测实时状态',
    meta: { title: '监测实时状态', icon: 'dashboard' },
    children: [
      {
        path: 'leakageCable',
        name: '漏缆实时状态',
        component: () => import('@/views/monitor/leakageCable'),
        meta: { title: '漏缆实时状态' }
      },
      {
        path: 'equipment',
        name: '设备实时状态',
        component: () => import('@/views/monitor/equipment'),
        meta: { title: '设备实时状态' }
      }
    ]
  },
  {
    path: '/maintain',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'maintain',
      name: 'Maintain',
      component: () => import('@/views/dashboard/index'),
      meta: { title: '维护管理', icon: 'dashboard' }
    }]
  },
  {
    path: '/history',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'history',
      name: 'History',
      component: () => import('@/views/dashboard/index'),
      meta: { title: '历史数据', icon: 'dashboard' }
    }]
  },
  {
    path: '/user',
    component: Layout,
    redirect: '/dashboard',
    name: 'User',
    meta: { title: '用户管理', icon: 'dashboard' },
    children: [{
      path: 'updateUser',
      name: 'UpdateUser',
      component: () => import('@/views/user/updateUser'),
      meta: { title: '个人信息管理', icon: 'dashboard' }
    },
    {
      path: 'userList',
      name: 'UserList',
      component: () => import('@/views/user/userList'),
      meta: { title: '用户信息列表', icon: 'dashboard' }
    }
    ]
  },

  {
    path: '/example',
    component: Layout,
    redirect: '/example/table',
    name: 'Example',
    meta: { title: 'Example', icon: 'example' },
    children: [
      {
        path: 'table',
        name: 'Table',
        component: () => import('@/views/table/index'),
        meta: { title: 'Table', icon: 'table' }
      },
      {
        path: 'tree',
        name: 'Tree',
        component: () => import('@/views/tree/index'),
        meta: { title: 'Tree', icon: 'tree' }
      }
    ]
  },

  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
